@@ -4,26 +4,22 @@
 # email:LeisureMam@gmail.com
 # datetime:2021-06-10 16:45
 # software: PyCharm
-from abc import ABC
+import json
 
 from protocol_helper.setting import SURVEILLANCE_SYSTEM_DOMAIN, SURVEILLANCE_SYSTEM_TOKEN
-from protocol_helper.utils.RequestBase import RequestBase
+from protocol_helper.utils import request
 
 
-class MonitoringCenterService(RequestBase, ABC):
+class MonitoringCenterService:
 
     def __init__(self):
-
         self.url = SURVEILLANCE_SYSTEM_DOMAIN
         self.token = SURVEILLANCE_SYSTEM_TOKEN
 
-        if self.token is None:
-            self._headers = {}
-        else:
-            self._headers = {
-                    'Authorization': f'Token {self.token}'
-            }
-        self.HEADERS = self._headers
+        self._headers = {
+                'Authorization': f'Token {self.token}',
+                'Content-Type':  'application/json'
+        }
 
     def support_service(self):
         """
@@ -31,7 +27,7 @@ class MonitoringCenterService(RequestBase, ABC):
         Returns:
 
         """
-        return self.get(f"{self.url}/api/collection").json()
+        return request.get(f"{self.url}/api/collection", headers = self._headers).json()
 
     def collection(self, mode, server_type, url):
         """
@@ -49,7 +45,7 @@ class MonitoringCenterService(RequestBase, ABC):
                 'server_type': server_type,
                 'url':         url
         }
-        return self.post(f"{self.url}/api/collection", data = data).json()
+        return request.post(f"{self.url}/api/collection", data = data, headers = self._headers).json()
 
     def available_agents(self):
         """
@@ -58,7 +54,7 @@ class MonitoringCenterService(RequestBase, ABC):
 
         """
 
-        return self.get(f"{self.url}/api/agent/").json()
+        return request.get(f"{self.url}/api/agent/", headers = self._headers).json()
 
     def agent_status_notify(self, server_name, status):
         """
@@ -74,7 +70,7 @@ class MonitoringCenterService(RequestBase, ABC):
                 'status':      status,
                 'server_name': server_name,
         }
-        return self.post(f"{self.url}/api/agent/", data = data).json()
+        return request.post(f"{self.url}/api/agent/", data = data, headers = self._headers).json()
 
     def get_proxy_configuration(self, server_name):
         """
@@ -86,7 +82,7 @@ class MonitoringCenterService(RequestBase, ABC):
 
         """
 
-        return self.get(f"{self.url}/api/agent/{server_name}/").json()
+        return request.get(f"{self.url}/api/agent/{server_name}/", headers = self._headers).json()
 
     def agent_lock(self, server_name, lock = 0):
         """
@@ -101,7 +97,7 @@ class MonitoringCenterService(RequestBase, ABC):
         data = {
                 'status': lock
         }
-        return self.post(f"{self.url}/api/agent/{server_name}/", data = data).json()
+        return request.post(f"{self.url}/api/agent/{server_name}/", data = data, headers = self._headers).json()
 
     def get_equipment_pool(self, equipment_type):
         """
@@ -112,7 +108,7 @@ class MonitoringCenterService(RequestBase, ABC):
         Returns:
 
         """
-        return self.get(f"{self.url}/api/equipment-pool/{equipment_type}").json()
+        return request.get(f"{self.url}/api/equipment-pool/{equipment_type}", headers = self._headers).json()
 
     def set_equipment_pool(self, equipment_type, _hash, status):
         """
@@ -129,7 +125,8 @@ class MonitoringCenterService(RequestBase, ABC):
                 'hash':   hash,
                 'status': status
         }
-        return self.post(f"{self.url}/api/equipment-pool/{equipment_type}", data = data).json()
+        return request.post(f"{self.url}/api/equipment-pool/{equipment_type}", data = data,
+                            headers = self._headers).json()
 
     def get_weibo_s(self, uid):
         """
@@ -144,7 +141,7 @@ class MonitoringCenterService(RequestBase, ABC):
         data = {
                 'uid': uid,
         }
-        return self.get(f"{self.url}/api/wb/get-s/", params = data).json()
+        return request.get(f"{self.url}/api/wb/get-s/", params = data, headers = self._headers).json()
 
     def get_weibo_registered_equipment(self):
         """
@@ -152,13 +149,18 @@ class MonitoringCenterService(RequestBase, ABC):
         Returns:
 
         """
-        return self.get(f"{self.url}/api/wb/registered-equipment").json()
+        return request.get(f"{self.url}/api/wb/registered-equipment", headers = self._headers).json()
 
-    def get_dy_sign(self,url,uid):
-        return self.post(f"{self.url}/api/dy/signature", data = {
-            'url': url,
-            'uid': uid
-        },headers={})
+    def get_dy_sign(self, url, uid, headers = None):
+        return request.post(f"{self.url}/api/dy/signature", data = {
+                'url': url,
+                'uid': uid
+        }, headers = headers)
+
+    def get_dy_pc_sign(self, url):
+        return request.post(f"{self.url}/api/dy/new_signature", data = {
+                'url': url
+        }, headers = self._headers)
 
     def get_oss_authorization(self):
         """
@@ -166,7 +168,7 @@ class MonitoringCenterService(RequestBase, ABC):
         Returns:
 
         """
-        return self.get(f'{self.url}/api/oss/get-authorization/').json()
+        return request.get(f'{self.url}/api/oss/authorize/', headers = self._headers).json()
 
     def upload_software_version(self, project_id, data):
         """
@@ -177,7 +179,7 @@ class MonitoringCenterService(RequestBase, ABC):
         Returns:
 
         """
-        return self.post(f'{self.url}/api/software/add-record/{project_id}/', data).json()
+        return request.post(f'{self.url}/api/software/add-record/{project_id}/', data, headers = self._headers).json()
 
     def get_dial_status(self, server_name):
         """
@@ -188,7 +190,7 @@ class MonitoringCenterService(RequestBase, ABC):
         Returns:
 
         """
-        return self.get(f'{self.url}/api/agent/{server_name}/').json()
+        return request.get(f'{self.url}/api/agent/{server_name}/', headers = self._headers).json()
 
     def get_proxy_detail(self, server_name):
         """
@@ -199,7 +201,7 @@ class MonitoringCenterService(RequestBase, ABC):
         Returns:
 
         """
-        return self.get(f'{self.url}/api/agent/{server_name}/').json()
+        return request.get(f'{self.url}/api/agent/{server_name}/', headers = self._headers).json()
 
     def report(self, service_name, status):
         """
@@ -215,7 +217,7 @@ class MonitoringCenterService(RequestBase, ABC):
                 "status":      status,
                 "server_name": service_name,
         }
-        return self.post(f'{self.url}/api/agent/', data = data).json()
+        return request.post(f'{self.url}/api/agent/', data = data, headers = self._headers).json()
 
     def get_project_detail(self, project_id) -> dict:
         """
@@ -223,4 +225,46 @@ class MonitoringCenterService(RequestBase, ABC):
         Returns:
 
         """
-        return self.get(f'{self.url}/api/project/{project_id}/').json()
+        return request.get(f'{self.url}/api/project/{project_id}/', headers = self._headers).json()
+
+    def get_error_orders(self, page_size = 100, is_queue = 1):
+        """
+        获取异常订单数据
+        Returns:
+
+        """
+        data = {
+                'page_size': page_size,
+                'is_queue':  is_queue
+        }
+        return request.get(f"{self.url}/api/error-order/", params = data, headers = self._headers).json()
+
+    def create_error_order(self, order_id):
+        """
+        获取异常订单数据
+        Args:
+            order_id:
+
+        Returns:
+
+        """
+        data = {
+                'order_id': order_id
+        }
+        return request.post(f"{self.url}/api/error-order/", data = json.dumps(data), headers = self._headers).json()
+
+    def update_error_order_status(self, order_id, status):
+        """
+        修改异常订单状态
+        Args:
+            order_id:
+            status:
+
+        Returns:
+
+        """
+        data = {
+                'order_id': order_id,
+                'status':   status
+        }
+        return request.put(f"{self.url}/api/error-order/", data = data, headers = self._headers).json()
