@@ -6,7 +6,7 @@
 # software: PyCharm
 import re
 
-from protocol_helper.Exceptions import CollectedDataError, DefaultException
+from protocol_helper.exceptions import CollectedDataError, DefaultException
 
 ALPHABET = "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"
 
@@ -266,23 +266,16 @@ class WeiBoBaseService(object):
 
         """
         page_info = status['page_info']
-        media_info = page_info['media_info']
+        if "media_info" in page_info.keys():
+            media_info = page_info['media_info']
+            video_url = media_info.get('h5_url', None) or media_info['h5_url']
 
-        return {
-                'page_id':     page_info['page_id'],
-                'object_type': page_info['object_type'],
-                'content1':    page_info['content1'],
-                'content2':    page_info['content2'],
-                'page_pic':    page_info['page_pic'],
-                'media_info':  {
-                        'name':                media_info['name'],
-                        'video_url':           media_info['h5_url'],
-                        'next_title':          media_info['next_title'],
-                        'media_id':            media_info['media_id'],
-                        'online_users':        media_info['online_users'],
-                        'online_users_number': media_info['online_users_number'],  # 播放次数
-                }
-        }
+            return {
+                    'video_url':           video_url,
+                    'online_users_number': media_info['online_users_number'],
+            }
+        else:
+            return {}
 
     def article_cleaning(self, data, url, urls):
         """
@@ -351,7 +344,11 @@ class WeiBoBaseService(object):
                 'is_app':          True,
                 'tip_msg':         tip_msg,
                 'header_text':     header_text,
-                'created_at':      self.cst_to_str(status['created_at'])
+                'created_at':      self.cst_to_str(status['created_at']),
+                'source':          status.get('source'),
+                'user_id':         str(user['id']),
+                'mbrank':          status['user']['mbrank'],
+                'edited':          status['edit_config']['edited']
         }
         try:
             data['pid'] = status['pid']
@@ -359,7 +356,7 @@ class WeiBoBaseService(object):
             pass
 
         # 获取视频信息
-        if 'page_info' in status.keys():
+        if 'page_info' in status.keys() and status.get('page_info', {}).get('object_type', '') == 'video':
             data.update({'video': self.__filter_video_information(status)})
 
         try:
@@ -377,12 +374,15 @@ class WeiBoBaseService(object):
                             content = retweeted_status['longText']['content']
                     else:
                         content = retweeted_status['text']
+                    name = retweeted_status.get('user', {}).get('name', None) or retweeted_status['user']['screen_name']
+                    friends_count = retweeted_status['user'].get('friends_count', None) or retweeted_status['user'][
+                        'follow_count']
                     retweeted_user = {
                             'id':             retweeted_status['user']['id'],
                             'screen_name':    retweeted_status['user']['screen_name'],
-                            'name':           retweeted_status['user']['name'],
+                            'name':           name,
                             'followers':      retweeted_status['user']['followers_count'],
-                            'friends_count':  retweeted_status['user']['friends_count'],
+                            'friends_count':  friends_count,
                             'statuses_count': retweeted_status['user']['statuses_count'],
                     }
                     if 'mblogid' in retweeted_status.keys():
@@ -405,7 +405,7 @@ class WeiBoBaseService(object):
 
                     # 获取视频信息
                     if 'page_info' in retweeted_status.keys():
-                        data.update({'video': self.__filter_video_information(status)})
+                        data.update({'video': self.__filter_video_information(retweeted_status)})
 
         except KeyError as key:
             raise Exception(f'获取转发信息失败:{key}')
@@ -518,6 +518,8 @@ class WeiBoBaseService(object):
         Returns:
 
         """
+        if data.get('state_code', None) != 0:
+            raise DefaultException(f"解析数据失败:{data}")
         status = data['status']
         root_comment = data['rootComment']
         user = {
