@@ -4,17 +4,16 @@
 # email:LeisureMam@gmail.com
 # datetime:2021-06-11 12:40
 # software: PyCharm
-
 import os
 from dotenv import load_dotenv
-from protocol_helper.Exceptions import NotSetDirectory
+from protocol_helper.exceptions import NotSetDirectory
 
 LOAD_PROJECT_PATH = os.environ.get('LOAD_PROJECT_PATH')
 
 if LOAD_PROJECT_PATH is None:
     raise NotSetDirectory
 try:
-    load_dotenv(os.path.join(LOAD_PROJECT_PATH, '.env'), encoding = 'gbk')
+    load_dotenv(os.path.join(LOAD_PROJECT_PATH, '.env'), encoding = 'utf-8')
 except UnicodeDecodeError as error:
     load_dotenv(os.path.join(LOAD_PROJECT_PATH, '.env'))
 except Exception as error:
